use std::collections::HashMap;

use librpm::db;
use librpm::Package;

// 获取当前系统已安装的所有 RPM 包
// 最后返回一个 map，其键为包名，因有多个版本可并存的软件包如 kernel，故其值为 `Vec<Package>`
pub fn get_installed_packages() -> HashMap<String, Vec<Package>> {
    let mut installed: HashMap<String, Vec<Package>> = HashMap::new();
    db::installed_packages().for_each(|pkg| {
        if let Some(rpms) = installed.get_mut(pkg.name()) {
            rpms.push(pkg.clone());
        } else {
            installed.insert(pkg.name().into(), vec![pkg.clone()]);
        }
    });

    installed
}

#[cfg(test)]
mod test {
    use super::*;
    
    #[test]
    fn get_installed_pkgs() {
        crate::configure();

        let pkgs = get_installed_packages();

        if let Some(_) = pkgs.get("kernel") {
            assert!(true);
        } else {
            assert_eq!("", "Package kernel not installed?");
        }
    }
}
